@@ -1,4 +1,5 @@
-# set temporary directories
+# Set the path to the temporary directory
+# This path is exported as $PLAYIT_WORKDIR.
 # USAGE: set_temp_directories
 set_temp_directories() {
 	debug_entering_function 'set_temp_directories'
@@ -20,17 +21,6 @@ set_temp_directories() {
 	debug_creating_directory "$PLAYIT_WORKDIR"
 	export PLAYIT_WORKDIR
 
-	# Export the path to the packages to build as PKG_xxx_PATH
-	# Some game scripts are expecting this variable to be set
-	# These should be updated to call `package_path` instead
-	local packages_list package package_path
-	packages_list=$(packages_list)
-	for package in $packages_list; do
-		package_path=$(package_path "$package")
-		eval "${package}_PATH='${package_path}'"
-		export "${package?}_PATH"
-	done
-
 	debug_leaving_function 'set_temp_directories'
 }
 
