@@ -4,8 +4,9 @@ error_invalid_version_string() {
 	local version_string
 	version_string="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='La valeur suivante de $script_version ne respecte pas le format attendu : %s\n'
 			message="$message"'Le format correct est "YYYYMMDD.N", avec "YYYYMMDD" la date de dernière édition du script, et "N" un nombre incrémenté si le script est édité plusieurs fois dans la même journée.\n'
