@@ -147,21 +147,16 @@ application_exe() {
 	printf '%s' "$application_exe"
 }
 
-# print the file name of the application, with single quotes escaped,
+# Print the path to the application binary, with single quotes escaped,
 # for inclusion in a single quote delimited variable declaration.
 # USAGE: application_exe_escaped $application
-# RETURN: the application file name with single quotes escaped
 application_exe_escaped() {
 	local application
 	application="$1"
 
 	local application_exe
 	application_exe=$(application_exe "$application")
-	## Check that application binary has been found
-	if [ -z "$application_exe" ]; then
-		error_application_exe_empty "$application" 'application_exe_escaped'
-		return 1
-	fi
+
 	# If the file name includes single quotes, replace each one with: '\''
 	printf '%s' "$application_exe" | sed "s/'/'\\\''/g"
 }
