@@ -4,8 +4,9 @@ information_file_in_use() {
 	local file
 	file="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Utilisation de %s\n'
 		;;
@@ -22,8 +23,9 @@ information_archive_data_extraction() {
 	local file
 	file="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Extraction des données de %s…\n'
 		;;
@@ -44,8 +46,9 @@ info_archive_hash_computation() {
 	local file_name
 	file_name=$(basename "$file_path")
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Calcul de la somme de contrôle de %s…\n'
 		;;
@@ -60,6 +63,7 @@ info_archive_hash_computation() {
 # display a list of archives, one per line, with their download URL if one is provided
 # USAGE: information_archives_list $archive[…]
 information_archives_list() {
+	## TODO: The archive URL should be fetched using a dedicated function.
 	local archive archive_name archive_url
 	for archive in "$@"; do
 		archive_name=$(archive_name "$archive")
@@ -75,13 +79,42 @@ information_archives_list() {
 	done
 }
 
+# Warning - An optional icons archive is supported, but not available
+# USAGE: warning_optional_archive_missing_icons $archive
+warning_optional_archive_missing_icons() {
+	local archive
+	archive="$1"
+
+	## TODO: The archive URL should be fetched using a dedicated function.
+	local archive_name archive_url
+	archive_name=$(archive_name "$archive")
+	archive_url=$(get_value "${archive}_URL")
+
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
+		('fr')
+			message='Une archive proposant des icônes pour ce jeu est disponible, mais n’a pas été trouvée : %s\n'
+			message="$message"'Elle peut être téléchargée depuis l’URL suivante : %s\n\n'
+		;;
+		('en'|*)
+			message='An archive providing icons for this game is available, but could not be found: %s\n'
+			message="$message"'It can be downloaded from the following URL: %s\n\n'
+		;;
+	esac
+	print_message 'warning' "$message" \
+		"$archive_name" \
+		"$archive_url"
+}
+
 # Error - No archive supported for the current game script
 error_no_archive_supported() {
 	local game_script
 	game_script=$(realpath "$0")
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Ce script semble ne prendre en charge aucune archive : %s\n'
 			message="$message"'Merci de signaler cette erreur sur notre outil de suivi : %s\n'
@@ -102,8 +135,9 @@ error_archive_no_extractor_found() {
 	local archive_type
 	archive_type="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Ce script a essayé dʼextraire le contenu dʼune archive de type "%s", mais aucun outil approprié nʼa été trouvé.\n'
 			message="$message"'Merci de signaler cette erreur sur notre outil de gestion de bugs : %s\n'
@@ -127,8 +161,9 @@ error_archive_not_found() {
 	archives_path=$(archives_path_base)
 	archives_path_full=$(realpath --no-symlinks "$archives_path")
 
-	local message_1 message_2
-	case "${LANG%_*}" in
+	local messages_language message_1 message_2
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			if [ $# -eq 1 ]; then
 				message_1='Le fichier suivant est introuvable dans %s :\n'
@@ -158,8 +193,9 @@ error_archive_type_not_set() {
 	local archive
 	archive="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='ARCHIVE_TYPE nʼest pas défini pour %s et nʼa pas pu être détecté automatiquement.\n'
 		;;
@@ -180,8 +216,9 @@ error_hashsum_mismatch() {
 	local file_name
 	file_name=$(basename "$file_path")
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Somme de contrôle incohérente. %s nʼest pas le fichier attendu.\n'
 			message="$message"'Utilisez --checksum=none pour forcer son utilisation.\n'
@@ -201,8 +238,9 @@ error_innoextract_version_too_old() {
 	local archive
 	archive="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='La version de innoextract disponible sur ce système est trop ancienne pour extraire les données de lʼarchive suivante : %s\n'
 			message="$message"'Des instructions de mise-à-jour sont proposées :\n'
@@ -230,8 +268,9 @@ error_archive_type_invalid() {
 	local archive_type
 	archive_type="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='La valeur suivante ne correspond pas à un type dʼarchive connu : "%s"\n'
 		;;
@@ -249,8 +288,9 @@ error_archive_extractor_invalid() {
 	local archive_extractor
 	archive_extractor="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='La valeur suivante ne correspond pas à un extracteur dʼarchive connu : "%s"\n'
 		;;
@@ -274,8 +314,9 @@ error_archive_extraction_failure() {
 	local log_file
 	log_file=$(archive_extraction_log_path)
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Lʼextraction des données depuis lʼarchive suivante a échoué : %s\n'
 			message="$message"'Vous pouvez obtenir plus de détails dans le fichier journal : %s\n'
