@@ -13,6 +13,9 @@ content_inclusion_icons() {
 		return 0
 	fi
 
+	# Ensure that the commands required for icons extraction are available
+	requirements_check_icons
+
 	# Get the package that should include the icons.
 	local package
 	if [ $# -ge 1 ]; then
@@ -24,6 +27,7 @@ content_inclusion_icons() {
 
 	# If an optional icons archive has been provided, use that instead of the icons shipped with the game
 	if archive_is_available 'ARCHIVE_ICONS'; then
+		information_icons_inclusion
 		content_inclusion_optional_icons_archive "$package"
 		## Return early if an optional icons archive has been used.
 		return 0
@@ -42,6 +46,8 @@ content_inclusion_icons() {
 		return 0
 	fi
 
+	information_icons_inclusion
+
 	local application
 	for application in "$@"; do
 		icons_inclusion_single_application "$package" "$application"
@@ -52,6 +58,8 @@ content_inclusion_icons() {
 # A list of default content identifiers is used.
 # USAGE: content_inclusion_default
 content_inclusion_default() {
+	information_content_inclusion
+
 	local packages_list
 	packages_list=$(packages_list)
 
@@ -97,10 +105,21 @@ content_inclusion_default() {
 # A list of default content identifiers is used, limited to native libraries for a single package.
 # USAGE: content_inclusion_default_libraries $package
 content_inclusion_default_libraries() {
-	local package package_suffix
+	local package
 	package="$1"
-	assert_not_empty 'package' 'content_inclusion_default_libraries'
+
+	local package_suffix files_list
 	package_suffix="${package#PKG_}"
+	files_list=$(context_name "CONTENT_LIBS_${package_suffix}_FILES")
+	if [ -z "$files_list" ]; then
+		## Check if a default files list is set for the current engine,
+		## return early otherwise.
+		local content_files
+		content_files=$(content_files "LIBS_${package_suffix}")
+		if [ -z "$content_files" ]; then
+			return 0
+		fi
+	fi
 
 	local target_directory
 	## On Arch Linux and Gentoo the libraries path can change based on the package architecture.
@@ -108,14 +127,13 @@ content_inclusion_default_libraries() {
 		set_current_package "$package"
 		path_libraries
 	)
-
 	content_inclusion "LIBS_${package_suffix}" "$package" "$target_directory"
-	local index files_list
+	local index
 	for index in $(seq 0 9); do
-		# Stop looping at the first unset files list
 		files_list=$(context_name "CONTENT_LIBS${index}_${package_suffix}_FILES")
 		if [ -z "$files_list" ]; then
-			break
+			## Stop looping at the first unset files list.
+			return 0
 		fi
 		content_inclusion "LIBS${index}_${package_suffix}" "$package" "$target_directory"
 	done
@@ -125,20 +143,31 @@ content_inclusion_default_libraries() {
 # A list of default content identifiers is used, limited to TTF fonts for a single package.
 # USAGE: content_inclusion_default_fonts $package
 content_inclusion_default_fonts() {
-	local package package_suffix
+	local package
 	package="$1"
+
+	local package_suffix files_list
 	package_suffix="${package#PKG_}"
+	files_list=$(context_name "CONTENT_FONTS_${package_suffix}_FILES")
+	if [ -z "$files_list" ]; then
+		## Check if a default files list is set for the current engine,
+		## return early otherwise.
+		local content_files
+		content_files=$(content_files "FONTS_${package_suffix}")
+		if [ -z "$content_files" ]; then
+			return 0
+		fi
+	fi
 
 	local target_directory
 	target_directory=$(path_fonts_ttf)
-
 	content_inclusion "FONTS_${package_suffix}" "$package" "$target_directory"
-	local index files_list
+	local index
 	for index in $(seq 0 9); do
-		# Stop looping at the first unset files list
 		files_list=$(context_name "CONTENT_FONTS${index}_${package_suffix}_FILES")
 		if [ -z "$files_list" ]; then
-			break
+			## Stop looping at the first unset files list.
+			return 0
 		fi
 		content_inclusion "FONTS${index}_${package_suffix}" "$package" "$target_directory"
 	done
@@ -148,72 +177,73 @@ content_inclusion_default_fonts() {
 # A list of default content identifiers is used, limited to game data files for a single package.
 # USAGE: content_inclusion_default_game_data $package
 content_inclusion_default_game_data() {
-	local package package_suffix
+	local package
 	package="$1"
-	assert_not_empty 'package' 'content_inclusion_default_game_data'
+
+	local package_suffix files_list
 	package_suffix="${package#PKG_}"
+	files_list=$(context_name "CONTENT_GAME_${package_suffix}_FILES")
+	if [ -z "$files_list" ]; then
+		## Try to parse legacy variables for old game scripts.
+		content_inclusion_default_game_data_legacy "$package"
+		## Check if a default files list is set for the current engine,
+		## return early otherwise.
+		local content_files
+		content_files=$(content_files "GAME_${package_suffix}")
+		if [ -z "$content_files" ]; then
+			return 0
+		fi
+	fi
 
 	local target_directory
 	target_directory=$(path_game_data)
-
 	content_inclusion "GAME_${package_suffix}" "$package" "$target_directory"
-	local index files_list
+	local index
 	for index in $(seq 0 9); do
-		# Stop looping at the first unset files list
 		files_list=$(context_name "CONTENT_GAME${index}_${package_suffix}_FILES")
 		if [ -z "$files_list" ]; then
-			break
+			## Stop looping at the first unset files list.
+			return 0
 		fi
 		content_inclusion "GAME${index}_${package_suffix}" "$package" "$target_directory"
 	done
 
-	# Try to parse legacy variables for old game scripts
-	if ! compatibility_level_is_at_least '2.19'; then
-		for index in $(seq 0 9); do
-			# Stop looping at the first unset files list
-			files_list=$(context_name "ARCHIVE_GAME${index}_${package_suffix}_FILES")
-			if [ -z "$files_list" ]; then
-				break
-			fi
-			content_inclusion "GAME${index}_${package_suffix}" "$package" "$target_directory"
-		done
-	fi
 }
 
 # Fetch files from the archive, and include them into the package skeleton.
 # A list of default content identifiers is used, limited to documentation files for a single package.
 # USAGE: content_inclusion_default_documentation $package
 content_inclusion_default_documentation() {
-	local package package_suffix
+	local package
 	package="$1"
-	assert_not_empty 'package' 'content_inclusion_default_documentation'
+
+	local package_suffix files_list
 	package_suffix="${package#PKG_}"
+	files_list=$(context_name "CONTENT_DOC_${package_suffix}_FILES")
+	if [ -z "$files_list" ]; then
+		## Try to parse legacy variables for old game scripts.
+		content_inclusion_default_game_documentation_legacy "$package"
+		## Check if a default files list is set for the current engine,
+		## return early otherwise.
+		local content_files
+		content_files=$(content_files "DOC_${package_suffix}")
+		if [ -z "$content_files" ]; then
+			return 0
+		fi
+	fi
 
 	local target_directory
 	target_directory=$(path_documentation)
-
 	content_inclusion "DOC_${package_suffix}" "$package" "$target_directory"
-	local index files_list
+	local index
 	for index in $(seq 0 9); do
-		# Stop looping at the first unset files list
 		files_list=$(context_name "CONTENT_DOC${index}_${package_suffix}_FILES")
 		if [ -z "$files_list" ]; then
-			break
+			## Stop looping at the first unset files list.
+			return 0
 		fi
 		content_inclusion "DOC${index}_${package_suffix}" "$package" "$target_directory"
 	done
-
-	# Try to parse legacy variables for old game scripts
-	if ! compatibility_level_is_at_least '2.19'; then
-		for index in $(seq 0 9); do
-			# Stop looping at the first unset files list
-			files_list=$(context_name "ARCHIVE_DOC${index}_${package_suffix}_FILES")
-			if [ -z "$files_list" ]; then
-				break
-			fi
-			content_inclusion "DOC${index}_${package_suffix}" "$package" "$target_directory"
-		done
-	fi
 }
 
 # Fetch files from the archive, and include them into the package skeleton.
@@ -224,6 +254,8 @@ content_inclusion() {
 	package="$2"
 	target_path="$3"
 
+	information_content_inclusion
+
 	# Check that the given package is valid
 	if ! package_is_included_in_packages_list "$package"; then
 		error_current_package_not_in_list "$package"
@@ -263,64 +295,86 @@ content_inclusion() {
 	destination_path=$(realpath --canonicalize-missing "${package_path}${target_path}")
 
 	# Proceed with the actual files inclusion
+	content_inclusion_include_paths "$content_id" "$destination_path"
+}
+
+# Convert a list of patterns to include into a series of find options
+# USAGE: content_inclusion_find_options $content_identifier
+# RETURN: a full find options string, using null-byte as separator
+content_inclusion_find_options() {
+	local content_identifier
+	content_identifier="$1"
+
+	local content_patterns_list
+	content_patterns_list=$(content_files "$content_identifier")
+
+	local content_pattern first_path_shown printf_format
+	first_path_shown=0
+	printf '.\0(\0'
+	while read -r content_pattern; do
+		## Skip empty lines.
+		if [ -z "$content_pattern" ]; then
+			continue
+		fi
+		if [ $first_path_shown -eq 0 ]; then
+			printf_format='-path\0./%s'
+			first_path_shown=1
+		else
+			printf_format='\0-o\0-path\0./%s'
+		fi
+		## Silence ShellCheck false-positive
+		## Don't use variables in the printf format string. Use printf "..%s.." "$foo".
+		# shellcheck disable=SC2059
+		printf -- "$printf_format" "${content_pattern#./}"
+	done <<- EOL
+	$(printf '%s' "$content_patterns_list")
+	EOL
+	printf '\0)\0-print0'
+}
+
+# Display the full list of paths to include, using a null-byte as the separator
+# USAGE: content_inclusion_list_paths $content_identifier
+# RETURN: a sorted list of paths, separated by null-bytes
+content_inclusion_list_paths() {
+	local content_identifier
+	content_identifier="$1"
+
+	local content_path content_path_full
+	content_path=$(content_path "$content_identifier")
+	content_path_full="${PLAYIT_WORKDIR}/gamedata/${content_path}"
 	(
 		cd "$content_path_full"
-		local file_pattern file_patterns
-		file_patterns=$(content_files "$content_id")
-		while read -r file_pattern; do
-			if [ -z "$file_pattern" ]; then
-				continue
-			fi
-			if [ -e "$file_pattern" ]; then
-				content_inclusion_include_file "$file_pattern" "$destination_path"
-			else
-				content_inclusion_include_pattern "$file_pattern" "$destination_path"
-			fi
-		done <<- EOF
-		$(printf '%s' "$file_patterns")
-		EOF
+		content_inclusion_find_options "$content_identifier" | xargs --null find
+	) | env --ignore-environment sort --zero-terminated
+}
+
+# Fetch a list of paths from the archives contents
+# USAGE: content_inclusion_include_paths $content_identifier $destination_path
+content_inclusion_include_paths() {
+	local content_identifier destination_path
+	content_identifier="$1"
+	destination_path="$2"
+
+	local content_path content_path_full paths_list_base64
+	content_path=$(content_path "$content_identifier")
+	content_path_full="${PLAYIT_WORKDIR}/gamedata/${content_path}"
+	mkdir --parents "$destination_path"
+	(
+		cd "$content_path_full"
+		## The list of paths is encoded in base64, because it uses null bytes as a separator and null bytes can not be stored in a variable.
+		paths_list_base64=$(content_inclusion_list_paths "$content_identifier" | base64 --wrap=0)
+		printf '%s' "$paths_list_base64" | base64 --decode | xargs --null --no-run-if-empty cp \
+			--force \
+			--link \
+			--recursive \
+			--no-dereference \
+			--parents \
+			--preserve=links \
+			--target-directory "$destination_path"
+		## Delete paths that have already been copied, so they will not end up duplicated in the packages.
+		printf '%s' "$paths_list_base64" | base64 --decode | xargs --null --no-run-if-empty rm \
+			--force \
+			--recursive
 	)
 }
 
-# Fetch a given file or directory from the archive,
-# identified by an explicit path.
-# Non existing files are skipped silently.
-# USAGE: content_inclusion_include_file $file_path $destination_path
-content_inclusion_include_file() {
-	local file_path destination_path
-	file_path="$1"
-	destination_path="$2"
-
-	# Skip silently files that are not found
-	if [ ! -e "$file_path" ]; then
-		return 0
-	fi
-
-	mkdir --parents "$destination_path"
-	cp \
-		--force \
-		--link \
-		--recursive \
-		--no-dereference \
-		--parents \
-		--preserve=links \
-		"$file_path" "$destination_path"
-	rm --force --recursive "$file_path"
-}
-
-# Fetch several files or directories from the archive,
-# identified by a pattern.
-# USAGE: content_inclusion_include_pattern $file_pattern $destination_path
-content_inclusion_include_pattern() {
-	local file_pattern destination_path
-	file_pattern="$1"
-	destination_path="$2"
-
-	local file_path
-	while read -r file_path; do
-		content_inclusion_include_file "$file_path" "$destination_path"
-	done <<- EOF
-	$(find . -path "./${file_pattern#./}")
-	EOF
-}
-
