@@ -9,6 +9,8 @@ packages_generation() {
 		return 0
 	fi
 
+	information_packages_generation
+
 	local option_package
 	option_package=$(option_value 'package')
 	case "$option_package" in
@@ -399,15 +401,6 @@ package_provides() {
 	local package_provides
 	package_provides=$(context_value "${package}_PROVIDES")
 
-	# Fall back to the legacy PKG_xxx_PROVIDE variable,
-	# for game scripts targeting ./play.it ≤ 2.23 only.
-	if \
-		[ -z "$package_provides" ] && \
-		! compatibility_level_is_at_least '2.24'
-	then
-		package_provides=$(package_provide_legacy "$package")
-	fi
-
 	# Return early if there is no package name to print
 	if [ -z "$package_provides" ]; then
 		return 0
