@@ -9,15 +9,17 @@ dependencies_list_generic() {
 	local dependencies_generic
 	dependencies_generic=$(context_value "${package}_DEPS")
 
-	# Fall back on the default list of generic dependencies for the current game engine
+	# Generic dependencies are deprecated for compatibility levels ≥ 2.30
+	if \
+		[ -n "$dependencies_generic" ] && \
+		compatibility_level_is_at_least '2.30'
+	then
+		warning_deprecated_variable "${package}_DEPS" "${package}_DEPENDENCIES_xxx"
+	fi
+
+	# Return early if the current package does not use legacy generic dependencies
 	if [ -z "$dependencies_generic" ]; then
-		local game_engine
-		game_engine=$(game_engine)
-		case "$game_engine" in
-			('visionaire')
-				dependencies_generic=$(visionaire_package_dependencies_generic  "$package")
-			;;
-		esac
+		return 0
 	fi
 
 	printf '%s' "$dependencies_generic" | sed 's/ /\n/g' | list_clean
