@@ -42,11 +42,10 @@ dosbox_launcher_environment() {
 	local application
 	application="$1"
 
-	local game_id path_game application_exe application_options
+	local game_id path_game application_exe
 	game_id=$(game_id)
 	path_game=$(path_game_data)
 	application_exe=$(application_exe_escaped "$application")
-	application_options=$(application_options "$application")
 
 	cat <<- EOF
 	# Set the environment
@@ -54,7 +53,6 @@ dosbox_launcher_environment() {
 	GAME_ID='$game_id'
 	PATH_GAME='$path_game'
 	APP_EXE='$application_exe'
-	APP_OPTIONS="$application_options"
 
 	EOF
 }
@@ -156,9 +154,7 @@ dosbox_launcher_instructions() {
 		$dosbox_prerun
 		EOF
 	fi
-	cat <<- 'EOF'
-	$APP_EXE $APP_OPTIONS $@
-	EOF
+	game_exec_line "$application"
 	if [ -n "$dosbox_postrun" ]; then
 		cat <<- EOF
 		$dosbox_postrun
@@ -169,3 +165,17 @@ dosbox_launcher_instructions() {
 	EOF
 }
 
+# DOSBOX - Print the line starting the game
+# USAGE: dosbox_exec_line $application
+# RETURN: the command to execute, including its command line options
+dosbox_exec_line() {
+	local application
+	application="$1"
+
+	local application_options
+	application_options=$(application_options "$application")
+	cat <<- EOF
+	\$APP_EXE $application_options \$@
+	EOF
+}
+
