@@ -46,15 +46,6 @@ wine_launcher() {
 			return 1
 		;;
 	esac
-
-	# Automatically add required dependencies to the current package
-	local winetricks_verbs
-	winetricks_verbs=$(wine_winetricks_verbs)
-	if [ -n "$winetricks_verbs" ]; then
-		local package
-		package=$(current_package)
-		dependencies_add_command "$package" 'winetricks'
-	fi
 }
 
 # WINE launcher - Set the environment
@@ -63,11 +54,10 @@ wine_launcher_environment() {
 	local application
 	application="$1"
 
-	local game_id path_game application_exe application_options
+	local game_id path_game application_exe
 	game_id=$(game_id)
 	path_game=$(path_game_data)
 	application_exe=$(application_exe_escaped "$application")
-	application_options=$(application_options "$application")
 
 	cat <<- EOF
 	# Set the environment
@@ -75,25 +65,22 @@ wine_launcher_environment() {
 	GAME_ID='$game_id'
 	PATH_GAME='$path_game'
 	APP_EXE='$application_exe'
-	APP_OPTIONS="$application_options"
 
 	EOF
-	{
-		cat <<- 'EOF'
-		## Print the path to the `wine` command
-		wine_command() {
-		    if [ -z "$PLAYIT_WINE_CMD" ]; then
-		        command -v wine
-		        return 0
-		    fi
-		    printf '%s' "$PLAYIT_WINE_CMD"
-		}
-		wineboot_command() {
-		    wine_command | sed 's#/wine$#/wineboot#'
-		}
+	cat <<- 'EOF'
+	## Print the path to the `wine` command
+	wine_command() {
+	    if [ -z "$PLAYIT_WINE_CMD" ]; then
+	        command -v wine
+	        return 0
+	    fi
+	    printf '%s' "$PLAYIT_WINE_CMD"
+	}
+	wineboot_command() {
+	    wine_command | sed 's#/wine$#/wineboot#'
+	}
 
-		EOF
-	} | sed --regexp-extended 's/( ){4}/\t/g'
+	EOF
 	## The `wineserver` command is only used by winetricks
 	local winetricks_verbs
 	winetricks_verbs=$(wine_winetricks_verbs)
@@ -101,28 +88,24 @@ wine_launcher_environment() {
 		[ -n "$winetricks_verbs" ] || \
 		[ -n "${WINE_DIRECT3D_RENDERER:-}" ]
 	then
-		{
-			cat <<- 'EOF'
-			wineserver_command() {
-			    wine_command | sed 's#/wine$#/wineserver#'
-			}
+		cat <<- 'EOF'
+		wineserver_command() {
+		    wine_command | sed 's#/wine$#/wineserver#'
+		}
 
-			EOF
-		} | sed --regexp-extended 's/( ){4}/\t/g'
+		EOF
 	fi
 	## Include the path to the `regedit` command only if it is going to be used
 	if \
 		[ -n "${APP_REGEDIT:-}" ] || \
 		[ -n "${WINE_REGEDIT_PERSISTENT_KEYS:-}" ]
 	then
-		{
-			cat <<- 'EOF'
-			regedit_command() {
-			    wine_command | sed 's#/wine$#/regedit#'
-			}
+		cat <<- 'EOF'
+		regedit_command() {
+		    wine_command | sed 's#/wine$#/regedit#'
+		}
 
-			EOF
-		} | sed --regexp-extended 's/( ){4}/\t/g'
+		EOF
 	fi
 
 	# Include the winetricks wrapper function only if it is going to be used
@@ -132,33 +115,38 @@ wine_launcher_environment() {
 		[ -n "$winetricks_verbs" ] || \
 		[ -n "${WINE_DIRECT3D_RENDERER:-}" ]
 	then
-		{
-			cat <<- 'EOF'
-			## Apply winetricks verbs, spawning a terminal if required
-			winetricks_wrapper() {
-			    ## Export custom paths to WINE commands
-			    ## so winetricks use them instead of the default paths
-			    WINE=$(wine_command)
-			    WINESERVER=$(wineserver_command)
-			    WINEBOOT=$(wineboot_command)
-			    export WINE WINESERVER WINEBOOT
+		cat <<- 'EOF'
+		## Apply winetricks verbs, spawning a terminal if required
+		winetricks_wrapper() {
+		    ## Export custom paths to WINE commands
+		    ## so winetricks use them instead of the default paths
+		    WINE=$(wine_command)
+		    WINESERVER=$(wineserver_command)
+		    WINEBOOT=$(wineboot_command)
+		    export WINE WINESERVER WINEBOOT
 
-			    ## Run winetricks, spawning a terminal if required
-			    ## to ensure it is not silently running in the background
-			    if [ -t 0 ] || command -v zenity kdialog >/dev/null; then
-			        winetricks "$@"
-			    elif command -v xterm >/dev/null; then
-			        xterm -e winetricks "$@"
-			    else
-			        winetricks "$@"
-			    fi
+		    ## Run winetricks, spawning a terminal if required
+		    ## to ensure it is not silently running in the background
+		    if [ -t 0 ] || command -v zenity kdialog >/dev/null; then
+		        winetricks "$@"
+		    elif command -v xterm >/dev/null; then
+		        xterm -e winetricks "$@"
+		    else
+		        winetricks "$@"
+		    fi
 
-			    ## Wait a bit for lingering WINE processes to terminate
-			    sleep 1s
-			}
+		    ## Wait a bit for lingering WINE processes to terminate
+		    sleep 1s
+		}
 
-			EOF
-		} | sed --regexp-extended 's/( ){4}/\t/g'
+		EOF
+	fi
+
+	# Include the screen resolution detection function if it is required to set a virtual desktop.
+	local virtual_desktop
+	virtual_desktop=$(wine_virtual_desktop)
+	if [ "$virtual_desktop" = 'auto' ]; then
+		wine_snippet_screen_resolution
 	fi
 }
 
@@ -178,10 +166,6 @@ wine_launcher_run() {
 	local game_engine
 	game_engine=$(game_engine)
 	case "$game_engine" in
-		('unity3d')
-			# Use a dedicated log file for the current game session
-			launcher_unity3d_dedicated_log
-		;;
 		('visionaire')
 			# Prevent the use of wayland SDL video driver
 			visionaire_tweak_sdl_wine
@@ -195,10 +179,11 @@ wine_launcher_run() {
 	## Do not exit on application failure,
 	## to ensure post-run commands are run.
 	set +o errexit
-	## Silence ShellCheck false-positive
-	## Double quote to prevent globbing and word splitting.
-	# shellcheck disable=SC2086
-	$(wine_command) "$APP_EXE" $APP_OPTIONS "$@"
+
+	EOF
+	game_exec_line "$application"
+	cat <<- 'EOF'
+
 	game_exit_status=$?
 	set -o errexit
 
@@ -207,3 +192,17 @@ wine_launcher_run() {
 	application_postrun "$application"
 }
 
+# WINE - Print the line starting the game
+# USAGE: wine_exec_line $application
+# RETURN: the command to execute, including its command line options
+wine_exec_line() {
+	local application
+	application="$1"
+
+	local application_options
+	application_options=$(application_options "$application")
+	cat <<- EOF
+	\$(wine_command) "\$APP_EXE" $application_options "\$@"
+	EOF
+}
+
