@@ -13,14 +13,12 @@ visionaire_tweak_sdl_native() {
 # Visionaire - Prevent the use of wayland SDL video driver, for use with WINE games
 # USAGE: visionaire_tweak_sdl_wine
 visionaire_tweak_sdl_wine() {
-	{
-		cat <<- 'EOF'
-		# Prevent the use of wayland SDL video driver
-		if [ "${SDL_VIDEODRIVER:-}" = 'wayland' ]; then
-		    unset SDL_VIDEODRIVER
-		fi
+	cat <<- 'EOF'
+	# Prevent the use of wayland SDL video driver
+	if [ "${SDL_VIDEODRIVER:-}" = 'wayland' ]; then
+	    unset SDL_VIDEODRIVER
+	fi
 
-		EOF
-	} | sed --regexp-extended 's/( ){4}/\t/g'
+	EOF
 }
 
