@@ -45,21 +45,19 @@ visionaire_package_description() {
 	printf '%s' "${package_description:-}"
 }
 
-# Visionaire - Get the list of generic dependencies for the given package
-# USAGE: visionaire_package_dependencies_generic $package
-# RETURN: a list of package ids,
+# Visionaire - Get the list of dependencies on siblings for the given package
+# USAGE: visionaire_package_dependencies_siblings $package
+# RETURN: a list of package identifiers,
 #         separated by line breaks
-visionaire_package_dependencies_generic() {
+visionaire_package_dependencies_siblings() {
 	local package
 	package="$1"
 
 	local package_dependencies
 	case "$package" in
 		('PKG_BIN')
-			local pkg_data_id
-			pkg_data_id=$(package_id 'PKG_DATA')
-			package_dependencies="
-			$pkg_data_id"
+			package_dependencies='
+			PKG_DATA'
 		;;
 	esac
 
