@@ -248,14 +248,10 @@ dependencies_archlinux_full_list() {
 	$(printf '%s' "$dependencies_generic")
 	EOL
 
-	# Include Arch-specific dependencies
-	local dependencies_specific
-	dependencies_specific=$(context_value "${package}_DEPS_ARCH")
-	if [ -n "$dependencies_specific" ]; then
-		packages_list=$(printf '%s\n' "$dependencies_specific" | sed 's/ /\n/g')
-		packages_list_full="$packages_list_full
-		$packages_list"
-	fi
+	# Include dependencies on sibling package
+	packages_list=$(archlinux_dependencies_siblings "$package")
+	packages_list_full="$packages_list_full
+	$packages_list"
 
 	# Include dependencies on commands
 	packages_list=$(archlinux_dependencies_all_commands "$package")
