@@ -122,14 +122,10 @@ dependencies_debian_full_list() {
 	$(printf '%s' "$dependencies_generic")
 	EOL
 
-	# Include Debian-specific dependencies
-	local dependencies_specific
-	dependencies_specific=$(context_value "${package}_DEPS_DEB")
-	if [ -n "$dependencies_specific" ]; then
-		packages_list=$(printf '%s\n' "$dependencies_specific" | sed 's/, \?/\n/g')
-		packages_list_full="$packages_list_full
-		$packages_list"
-	fi
+	# Include dependencies on sibling package
+	packages_list=$(debian_dependencies_siblings "$package")
+	packages_list_full="$packages_list_full
+	$packages_list"
 
 	# Include dependencies on commands
 	packages_list=$(debian_dependencies_all_commands "$package")
