@@ -23,10 +23,7 @@ debian_dependencies_all_commands() {
 	$(printf '%s' "$required_commands")
 	EOL
 
-	printf '%s' "$packages_list" | \
-		sed 's/^\s*//g' | \
-		grep --invert-match --regexp='^$' | \
-		sort --unique
+	printf '%s' "$packages_list" | list_clean
 }
 
 # Debian - Print the package names providing the required command
@@ -76,6 +73,10 @@ debian_dependencies_single_command() {
 			package_names='
 			pulseaudio:amd64 | pulseaudio'
 		;;
+		('renpy')
+			package_names='
+			renpy'
+		;;
 		('scummvm')
 			package_names='
 			scummvm'
