@@ -11,10 +11,7 @@ debian_dependencies_providing_native_libraries() {
 		$package"
 	done
 
-	printf '%s' "$packages_list" | \
-		sed 's/^\s*//g' | \
-		grep --invert-match --regexp='^$' | \
-		sort --unique
+	printf '%s' "$packages_list" | list_clean
 }
 
 # Debian - Print the package name providing the given native library
@@ -71,14 +68,8 @@ dependency_package_providing_library_deb() {
 		('libaudio.so.2')
 			package_name='libaudio2'
 		;;
-		('libavcodec.so.58')
-			package_name='libavcodec58 | libavcodec-extra58'
-		;;
-		('libavformat.so.58')
-			package_name='libavformat58 | libavformat-extra58'
-		;;
-		('libavutil.so.56')
-			package_name='libavutil56'
+		('libboost_locale.so.1.74.0')
+			package_name='libboost-locale1.74.0'
 		;;
 		('libbz2.so.1.0'|'libbz2.so.1')
 			package_name='libbz2-1.0'
@@ -124,6 +115,9 @@ dependency_package_providing_library_deb() {
 		('libdbus-1.so.3')
 			package_name='libdbus-1-3'
 		;;
+		('libdbus-glib-1.so.2')
+			package_name='libdbus-glib-1-2'
+		;;
 		('libdl.so.2')
 			package_name='libc6'
 		;;
@@ -157,7 +151,9 @@ dependency_package_providing_library_deb() {
 			package_name='libgcc-s1'
 		;;
 		('libgconf-2.so.4')
-			package_name='libgconf-2-4'
+			# This native library is provided by an extra archive:
+			# https://downloads.dotslashplay.it/resources/gconf/
+			return 0
 		;;
 		('libgcrypt.so.11')
 			# This old library is no longer available from Debian.
@@ -278,6 +274,9 @@ dependency_package_providing_library_deb() {
 		('libnghttp2.so.14')
 			package_name='libnghttp2-14'
 		;;
+		('libnotify.so.4')
+			package_name='libnotify4'
+		;;
 		('libnspr4.so')
 			package_name='libnspr4'
 		;;
@@ -431,6 +430,9 @@ dependency_package_providing_library_deb() {
 		('libtheoradec.so.1')
 			package_name='libtheora0'
 		;;
+		('libtheoraenc.so.1')
+			package_name='libtheora0'
+		;;
 		('libthread_db.so.1')
 			package_name='libc6'
 		;;
@@ -553,3 +555,4 @@ dependency_package_providing_library_deb() {
 
 	dependencies_unknown_libraries_add "$library"
 }
+
