@@ -145,16 +145,20 @@ dependencies_gentoo_full_list() {
 	$(printf '%s' "$dependencies_generic")
 	EOL
 
-	# Include Gentoo-specific dependencies
-	local dependencies_specific
-	dependencies_specific=$(context_value "${package}_DEPS_GENTOO")
-	if [ -n "$dependencies_specific" ]; then
-		printf '%s\n' "$dependencies_specific"
-	fi
-
 	local packages_list packages_list_full
 	packages_list_full=''
 
+	# Include dependencies on sibling package (not when building "egentoo" merged packages)
+	local option_package
+	option_package=$(option_value 'package')
+	case "$option_package" in
+		('gentoo')
+			packages_list=$(gentoo_dependencies_siblings "$package")
+			packages_list_full="$packages_list_full
+			$packages_list"
+		;;
+	esac
+
 	# Include dependencies on commands
 	packages_list=$(gentoo_dependencies_all_commands "$package")
 	packages_list_full="$packages_list_full
