@@ -23,10 +23,7 @@ gentoo_dependencies_all_commands() {
 	$(printf '%s' "$required_commands")
 	EOL
 
-	printf '%s' "$packages_list" | \
-		sed 's/^\s*//g' | \
-		grep --invert-match --regexp='^$' | \
-		sort --unique
+	printf '%s' "$packages_list" | list_clean
 }
 
 # Gentoo - Print the package names providing the required command
@@ -76,9 +73,13 @@ gentoo_dependencies_single_command() {
 			package_names='
 			media-sound/pulseaudio'
 		;;
+		('renpy')
+			package_names='
+			games-engines/renpy'
+		;;
 		('scummvm')
 			package_names='
-			games-engines/scummvm'
+			games-engines/scummvm[mp3,truetype,opengl,vorbis,theora]'
 		;;
 		('sed')
 			package_names='
