@@ -15,10 +15,7 @@ gentoo_dependencies_providing_native_libraries() {
 		$native_package"
 	done
 
-	printf '%s' "$native_packages_list" | \
-		sed 's/^\s*//g' | \
-		grep --invert-match --regexp='^$' | \
-		sort --unique
+	printf '%s' "$native_packages_list" | list_clean
 }
 
 # Gentoo - Print the package names providing the given native libraries in a 32-bit build
@@ -38,10 +35,7 @@ gentoo_dependencies_providing_native_libraries_32bit() {
 		$native_package"
 	done
 
-	printf '%s' "$native_packages_list" | \
-		sed 's/^\s*//g' | \
-		grep --invert-match --regexp='^$' | \
-		sort --unique
+	printf '%s' "$native_packages_list" | list_clean
 }
 
 # Gentoo - Print the package name providing the given native library
@@ -99,14 +93,9 @@ dependency_package_providing_library_gentoo() {
 		('libaudio.so.2')
 			package_name='media-libs/nas'
 		;;
-		('libavcodec.so.58')
-			package_name='media-video/ffmpeg'
-		;;
-		('libavformat.so.58')
-			package_name='media-video/ffmpeg'
-		;;
-		('libavutil.so.56')
-			package_name='media-video/ffmpeg'
+		('libboost_locale.so.1.74.0')
+			# This library is not provided for Gentoo
+			unset package_name
 		;;
 		('libbz2.so.1.0'|'libbz2.so.1')
 			package_name='app-arch/bzip2'
@@ -156,6 +145,9 @@ dependency_package_providing_library_gentoo() {
 		('libdbus-1.so.3')
 			package_name='sys-apps/dbus'
 		;;
+		('libdbus-glib-1.so.2')
+			package_name='dev-libs/dbus-glib'
+		;;
 		('libdl.so.2')
 			package_name='sys-libs/glibc'
 		;;
@@ -189,7 +181,9 @@ dependency_package_providing_library_gentoo() {
 			package_name='sys-devel/gcc'
 		;;
 		('libgconf-2.so.4')
-			package_name='gnome-base/gconf'
+			# This native library is provided by an extra archive:
+			# https://downloads.dotslashplay.it/resources/gconf/
+			return 0
 		;;
 		('libgcrypt.so.11')
 			package_name='dev-libs/libgcrypt-compat'
@@ -307,6 +301,9 @@ dependency_package_providing_library_gentoo() {
 		('libnghttp2.so.14')
 			package_name='net-libs/nghttp2'
 		;;
+		('libnotify.so.4')
+			package_name='x11-libs/libnotify'
+		;;
 		('libnspr4.so')
 			package_name='dev-libs/nspr'
 		;;
@@ -460,6 +457,9 @@ dependency_package_providing_library_gentoo() {
 		('libtheoradec.so.1')
 			package_name='media-libs/libtheora'
 		;;
+		('libtheoraenc.so.1')
+			package_name='media-libs/libtheora'
+		;;
 		('libthread_db.so.1')
 			package_name='sys-libs/glibc'
 		;;
@@ -639,14 +639,9 @@ dependency_package_providing_library_gentoo32() {
 		('libaudio.so.2')
 			package_name='media-libs/nas[abi_x86_32]'
 		;;
-		('libavcodec.so.58')
-			package_name='media-video/ffmpeg[abi_x86_32]'
-		;;
-		('libavformat.so.58')
-			package_name='media-video/ffmpeg[abi_x86_32]'
-		;;
-		('libavutil.so.56')
-			package_name='media-video/ffmpeg[abi_x86_32]'
+		('libboost_locale.so.1.74.0')
+			# This library is not provided for Gentoo
+			unset package_name
 		;;
 		('libbz2.so.1.0'|'libbz2.so.1')
 			package_name='app-arch/bzip2[abi_x86_32]'
@@ -696,6 +691,9 @@ dependency_package_providing_library_gentoo32() {
 		('libdbus-1.so.3')
 			package_name='sys-apps/dbus[abi_x86_32]'
 		;;
+		('libdbus-glib-1.so.2')
+			package_name='dev-libs/dbus-glib[abi_x86_32]'
+		;;
 		('libdl.so.2')
 			package_name='sys-libs/glibc amd64? ( sys-libs/glibc[multilib] )'
 		;;
@@ -729,7 +727,9 @@ dependency_package_providing_library_gentoo32() {
 			package_name='sys-devel/gcc[abi_x86_32]'
 		;;
 		('libgconf-2.so.4')
-			package_name='gnome-base/gconf[abi_x86_32]'
+			# This native library is provided by an extra archive:
+			# https://downloads.dotslashplay.it/resources/gconf/
+			return 0
 		;;
 		('libgcrypt.so.11')
 			package_name='dev-libs/libgcrypt-compat[abi_x86_32]'
@@ -847,6 +847,9 @@ dependency_package_providing_library_gentoo32() {
 		('libnghttp2.so.14')
 			package_name='net-libs/nghttp2[abi_x86_32]'
 		;;
+		('libnotify.so.4')
+			package_name='x11-libs/libnotify[abi_x86_32]'
+		;;
 		('libnspr4.so')
 			package_name='dev-libs/nspr[abi_x86_32]'
 		;;
@@ -1000,6 +1003,9 @@ dependency_package_providing_library_gentoo32() {
 		('libtheoradec.so.1')
 			package_name='media-libs/libtheora[abi_x86_32]'
 		;;
+		('libtheoraenc.so.1')
+			package_name='media-libs/libtheora[abi_x86_32]'
+		;;
 		('libthread_db.so.1')
 			package_name='sys-libs/glibc amd64? ( sys-libs/glibc[multilib] )'
 		;;
@@ -1123,3 +1129,4 @@ dependency_package_providing_library_gentoo32() {
 
 	dependencies_unknown_libraries_add "$library"
 }
+
