@@ -93,29 +93,6 @@ debug_creating_directory() {
 	return 0
 }
 
-# print the type of the launcher being created
-# USAGE: debug_write_launcher $launcher_type
-debug_write_launcher() {
-	local option_debug
-	option_debug=$(option_value 'debug')
-	if [ "$option_debug" -eq 0 ]; then
-		return 0
-	fi
-
-	local launcher_type binary_file
-	launcher_type="$1"
-	binary_file="$2"
-	assert_not_empty 'launcher_type' 'debug_write_launcher'
-
-	print_debug
-	if [ -z "$binary_file" ]; then
-		printf 'Writing launcher: %s\n' "$launcher_type" >> /dev/stderr
-	else
-		printf 'Writing %s launcher: %s\n' "$launcher_type" "$binary_file" >> /dev/stderr
-	fi
-	return 0
-}
-
 # print an external command
 # USAGE: debug_external_command $command
 debug_external_command() {
