@@ -31,6 +31,13 @@ if [ "$(basename "$0")" != 'libplayit2.sh' ] && [ -z "$LIB_ONLY" ]; then
 
 	option_list_supported_games=$(option_value 'list-supported-games')
 	if [ "${option_list_supported_games:-0}" -eq 1 ]; then
+		## Set the default package, used by the context system when no explicit package context is set.
+		## It is required by the context system, but is usually set later, when the current archive has been set already.
+		packages_list=$(packages_list)
+		default_package=$(printf '%s' "$packages_list" | head --lines=1)
+		set_default_package "$default_package"
+		unset packages_list default_package
+
 		games_list_supported
 		exit 0
 	fi
@@ -119,6 +126,13 @@ if [ "$(basename "$0")" != 'libplayit2.sh' ] && [ -z "$LIB_ONLY" ]; then
 
 	archive_initialize_base
 
+	# Set the default package, used by the context system when no explicit package context is set
+
+	packages_list=$(packages_list)
+	default_package=$(printf '%s' "$packages_list" | head --lines=1)
+	set_default_package "$default_package"
+	unset packages_list default_package
+
 	# Set the path to the temporary directory used by ./play.it.
 	# This can not be set earlier, because GAME_ID (required to compute this path) might be unset before the call to archive_initialize_base.
 
