@@ -7,20 +7,13 @@ oneTimeSetUp() {
 }
 
 test_set_current_archive() {
-	local PLAYIT_CONTEXT_ARCHIVE PLAYIT_COMPATIBILITY_LEVEL
+	local PLAYIT_CONTEXT_ARCHIVE
 
 	set_current_archive 'ARCHIVE_BASE_0'
 	assertEquals 'ARCHIVE_BASE_0' "$PLAYIT_CONTEXT_ARCHIVE"
-	unset PLAYIT_CONTEXT_ARCHIVE
 
 	# Check that the format ARCHIVE_BASE_xxx is enforced
 	assertFalse 'set_current_archive "ARCHIVE_GOG_OLD0"'
-	unset PLAYIT_CONTEXT_ARCHIVE
-
-	# Check that the old format ARCHIVE_xxx is allowed when targeting compatibility level < 2.21
-	PLAYIT_COMPATIBILITY_LEVEL='2.20'
-	assertTrue 'set_current_archive "ARCHIVE_GOG_OLD0"'
-	unset PLAYIT_CONTEXT_ARCHIVE
 }
 
 test_set_current_package() {
@@ -28,18 +21,31 @@ test_set_current_package() {
 
 	set_current_package 'PKG_MAIN'
 	assertEquals 'PKG_MAIN' "$PLAYIT_CONTEXT_PACKAGE"
-	unset PLAYIT_CONTEXT_PACKAGE
 
 	# Check that the format PKG_xxx is enforced
 	assertFalse 'set_current_package "PACKAGE_MAIN"'
-	unset PLAYIT_CONTEXT_PACKAGE
 
 	# An error should be thrown when trying to set a package that is not included in the list of packages to build.
 	PACKAGES_LIST='
 	PKG_BIN
 	PKG_DATA'
 	assertFalse 'set_current_package "PKG_BIN32"'
-	unset PLAYIT_CONTEXT_PACKAGE PACKAGES_LIST
+}
+
+test_set_default_package() {
+	local PLAYIT_CONTEXT_PACKAGE_DEFAULT PACKAGES_LIST
+
+	set_default_package 'PKG_MAIN'
+	assertEquals 'PKG_MAIN' "$PLAYIT_CONTEXT_PACKAGE_DEFAULT"
+
+	# Check that the format PKG_xxx is enforced
+	assertFalse 'set_default_package "PACKAGE_MAIN"'
+
+	# An error should be thrown when trying to set a package that is not included in the list of packages to build.
+	PACKAGES_LIST='
+	PKG_BIN
+	PKG_DATA'
+	assertFalse 'set_default_package "PKG_BIN32"'
 }
 
 test_current_archive() {
@@ -72,53 +78,48 @@ test_current_archive() {
 }
 
 test_current_package() {
-	local current_package PLAYIT_COMPATIBILITY_LEVEL PLAYIT_CONTEXT_PACKAGE PACKAGES_LIST PKG
+	local PACKAGES_LIST PLAYIT_CONTEXT_PACKAGE_DEFAULT PLAYIT_CONTEXT_PACKAGE PLAYIT_COMPATIBILITY_LEVEL PKG
 
-	set_current_package 'PKG_MAIN'
-	current_package=$(current_package)
-	assertEquals 'PKG_MAIN' "$current_package"
-	unset PLAYIT_CONTEXT_PACKAGE
+	assertNull "$(current_package)"
 
-	PACKAGES_LIST='
-	PKG_BIN
-	PKG_DATA'
-	current_package=$(current_package)
-	assertEquals 'PKG_BIN' "$current_package"
-	unset PLAYIT_CONTEXT_PACKAGE PACKAGES_LIST
-
-	# Set the current package using the legacy global variable
-	PLAYIT_COMPATIBILITY_LEVEL='2.25'
-	PKG='PKG_BIN32'
-	current_package=$(current_package)
-	assertEquals 'PKG_BIN32' "$current_package"
-	unset PLAYIT_COMPATIBILITY_LEVEL PLAYIT_CONTEXT_PACKAGE PKG
-
-	# Check the priority order between the current context system and the legacy one.
-	PLAYIT_COMPATIBILITY_LEVEL='2.25'
 	PACKAGES_LIST='
 	PKG_BIN32
 	PKG_BIN64
+	PKG_L10N
 	PKG_DATA'
-	set_current_package 'PKG_BIN32'
-	PKG='PKG_BIN64'
+	set_default_package 'PKG_BIN32'
+	assertEquals 'PKG_BIN32' "$(current_package)"
+
+	set_current_package 'PKG_BIN64'
+	assertEquals 'PKG_BIN64' "$(current_package)"
+
+	# Backwards compatibility with compatibility level ≤ 2.25
+	PLAYIT_COMPATIBILITY_LEVEL='2.25'
+	## Set the current package using the legacy global variable
+	PKG='PKG_L10N'
+	assertEquals 'PKG_L10N' "$(current_package)"
+	## Check the priority order between the current context system and the legacy one
+	PKG='PKG_DATA'
 	current_package=$(current_package)
 	assertEquals \
 		'current_package ignored the value of $PKG because set_current_package has been used. This will break compatibility with game scripts relying on the ability to set the context using $PKG.' \
-		'PKG_BIN64' "$current_package"
-	unset PLAYIT_COMPATIBILITY_LEVEL PLAYIT_CONTEXT_PACKAGE PACKAGES_LIST PKG
+		'PKG_DATA' "$(current_package)"
+}
+
+test_default_package() {
+	local PLAYIT_CONTEXT_PACKAGE_DEFAULT
+
+	assertNull "$(default_package)"
+
+	set_default_package 'PKG_MAIN'
+	assertEquals 'PKG_MAIN' "$(default_package)"
 }
 
 test_current_archive_suffix() {
-	local current_archive_suffix PLAYIT_CONTEXT_ARCHIVE PLAYIT_COMPATIBILITY_LEVEL ARCHIVE
+	local PLAYIT_CONTEXT_ARCHIVE
 
 	set_current_archive 'ARCHIVE_BASE_MULTIARCH_0'
-	current_archive_suffix=$(current_archive_suffix)
-	assertEquals '_MULTIARCH_0' "$current_archive_suffix"
-
-	PLAYIT_COMPATIBILITY_LEVEL='2.20'
-	set_current_archive 'ARCHIVE_OLD0'
-	current_archive_suffix=$(current_archive_suffix)
-	assertEquals '_OLD0' "$current_archive_suffix"
+	assertEquals '_MULTIARCH_0' "$(current_archive_suffix)"
 }
 
 test_current_package_suffix() {
