@@ -26,9 +26,6 @@ test_set_temp_directories() {
 
 	assertTrue "test -n '$PLAYIT_WORKDIR'"
 	assertTrue "test -d '$PLAYIT_WORKDIR'"
-
-	# Check that the legacy PKG_xxx_PATH variables are set
-	assertTrue "test -n '$PKG_MAIN_PATH'"
 }
 
 test_temporary_directory_path() {
