@@ -120,39 +120,17 @@ test_application_exe_escaped() {
 
 test_application_exe_path() {
 	local \
-		PLAYIT_OPTION_TMPDIR GAME_ID APP_MAIN_EXE \
-		CONTENT_PATH_DEFAULT fake_binary application_exe_path \
-		PLAYIT_CONTEXT_PACKAGE PKG_MAIN_ID \
-		PACKAGES_LIST PKG_BIN32_ID PKG_BIN64_ID PKG_DATA_ID
+		PLAYIT_OPTION_TMPDIR GAME_ID CONTENT_PATH_DEFAULT APP_MAIN_EXE \
+		PACKAGES_LIST PKG_BIN32_ID PKG_BIN64_ID PKG_DATA_ID \
+		PLAYIT_WORKDIR \
+		application_exe_path_gamedata application_exe_path_bin32 application_exe_path_bin64 application_exe_path_data \
+		PLAYIT_CONTEXT_PACKAGE_DEFAULT PLAYIT_CONTEXT_PACKAGE
 
 	# Create a couple files in the temporary directory, and set required variables.
 	PLAYIT_OPTION_TMPDIR="$TEST_TEMP_DIR"
 	GAME_ID='some-game'
-	APP_MAIN_EXE='SomeGame.exe'
-	set_temp_directories
-	mkdir --parents \
-		"${PLAYIT_WORKDIR}/gamedata" \
-		"${PLAYIT_WORKDIR}/packages/some-game-main_1.0-1+19700101.1_all/usr/share/games/some-game" \
-		"${PLAYIT_WORKDIR}/packages/some-game-bin64_1.0-1+19700101.1_all/usr/share/games/some-game"
-	touch \
-		"${PLAYIT_WORKDIR}/gamedata/SomeGame.exe" \
-		"${PLAYIT_WORKDIR}/packages/some-game-main_1.0-1+19700101.1_all/usr/share/games/some-game/SomeGame.exe" \
-		"${PLAYIT_WORKDIR}/packages/some-game-bin64_1.0-1+19700101.1_all/usr/share/games/some-game/SomeGame.exe"
-
-	# Look in archive contents
 	CONTENT_PATH_DEFAULT='.'
-	application_exe_path=$(application_exe_path "$APP_MAIN_EXE")
-	assertEquals "${PLAYIT_WORKDIR}/gamedata/./SomeGame.exe" "$application_exe_path"
-	unset CONTENT_PATH_DEFAULT
-
-	# Look in the current package
-	set_current_package 'PKG_MAIN'
-	PKG_MAIN_ID='some-game-main'
-	application_exe_path=$(application_exe_path "$APP_MAIN_EXE")
-	assertEquals "${PLAYIT_WORKDIR}/packages/some-game-main_1.0-1+19700101.1_all/usr/share/games/some-game/SomeGame.exe" "$application_exe_path"
-	unset PKG PKG_MAIN_ID PLAYIT_CONTEXT_PACKAGE
-
-	# Look in all packages
+	APP_MAIN_EXE='SomeGame.exe'
 	PACKAGES_LIST='
 	PKG_BIN32
 	PKG_BIN64
@@ -160,9 +138,35 @@ test_application_exe_path() {
 	PKG_BIN32_ID='some-game-bin32'
 	PKG_BIN64_ID='some-game-bin64'
 	PKG_DATA_ID='some-game-data'
-	application_exe_path=$(application_exe_path "$APP_MAIN_EXE")
-	assertEquals "${PLAYIT_WORKDIR}/packages/some-game-bin64_1.0-1+19700101.1_all/usr/share/games/some-game/SomeGame.exe" "$application_exe_path"
-	unset PACKAGES_LIST PKG_BIN32_ID PKG_BIN64_ID PKG_DATA_ID
+	set_default_package 'PKG_BIN32'
+	set_temp_directories
+	application_exe_path_gamedata="${PLAYIT_WORKDIR}/gamedata/${CONTENT_PATH_DEFAULT}/${APP_MAIN_EXE}"
+	application_exe_path_bin32="${PLAYIT_WORKDIR}/packages/${PKG_BIN32_ID}_1.0-1+19700101.1_all/usr/share/games/${GAME_ID}/${APP_MAIN_EXE}"
+	application_exe_path_bin64="${PLAYIT_WORKDIR}/packages/${PKG_BIN64_ID}_1.0-1+19700101.1_all/usr/share/games/${GAME_ID}/${APP_MAIN_EXE}"
+	application_exe_path_data="${PLAYIT_WORKDIR}/packages/${PKG_DATA_ID}_1.0-1+19700101.1_all/usr/share/games/${GAME_ID}/${APP_MAIN_EXE}"
+	mkdir --parents \
+		"$(dirname "$application_exe_path_gamedata")" \
+		"$(dirname "$application_exe_path_bin32")" \
+		"$(dirname "$application_exe_path_bin64")" \
+		"$(dirname "$application_exe_path_data")"
+	touch \
+		"$application_exe_path_gamedata" \
+		"$application_exe_path_bin32" \
+		"$application_exe_path_bin64" \
+		"$application_exe_path_data"
+
+	# Look in archive contents
+	assertEquals "$application_exe_path_gamedata" "$(application_exe_path "$APP_MAIN_EXE")"
+	rm "$application_exe_path_gamedata"
+
+	# Look in the current package
+	set_current_package 'PKG_BIN64'
+	assertEquals "$application_exe_path_bin64" "$(application_exe_path "$APP_MAIN_EXE")"
+	rm "$application_exe_path_bin32" "$application_exe_path_bin64"
+
+	# Look in all packages
+	assertEquals "$application_exe_path_data" "$(application_exe_path "$APP_MAIN_EXE")"
+	rm "$application_exe_path_data"
 }
 
 test_application_name() {
