@@ -16,7 +16,8 @@ test_packages_generation() {
 		export function_calls_counter
 	}
 	debian_packages_build() { return 0; }
-	packages_generation
+	## Prevent the console message from being mixed with shunit2 output.
+	packages_generation >/dev/null
 	assertEquals \
 		'packages_generation called without an argument ended up running multiple times instead of only once.' \
 		'1' "$function_calls_counter"
